
[TOC]

## Components

### Kaniko build
The `kaniko-build` CI/CD component provides a template to build Docker images within a pipeline using [Kaniko](https://github.com/GoogleContainerTools/kaniko).
By default, it runs only for tagged commits.

#### Parameter

| Parameter           | Variable            | Description                                                         | Type     | Default                 |
| ------------------- | ------------------- | ------------------------------------------------------------------- | -------- | ----------------------- |
| `stage`             |                     | Stage of the CI/CD job                                              | `string` | `build`                 |
| `job_name`          |                     | Name of the CI/CD job                                               | `string` | `kaniko-build`          |
| `dockerfile`        | `DOCKERFILE`        | Path of the Dockerfile relative to the project directory.           | `string` | `Dockerfile`            |
| `image_repo`        | `IMAGE_REPO`        | Name of the Docker repository including the registry path           | `string` | `$CI_REGISTRY_IMAGE`    |
| `image_tag`         | `IMAGE_TAG`         | Tag of the Docker image                                             | `string` | `$CI_COMMIT_TAG`        |
| `context`           | `CONTEXT`           | Project directory and docker context.                               | `string` | `$CI_PROJECT_DIR`       |
| `registry`          | `REGISTRY`          | Hostname (and port) of the Docker registry to which the job logs in | `string` | `$CI_REGISTRY`          |
| `registry_user`     | `REGISTRY_USER`     | Username to authenticate with the Docker registry                   | `string` | `$CI_REGISTRY_USER`     |
| `registry_password` | `REGISTRY_PASSWORD` | Password to authenticate with the Docker registry                   | `string` | `$CI_REGISTRY_PASSWORD` |
| `cache_repo`        | `CACHE_REPO`        | Name of the Docker repository used to cache layers                  | `string` | `$CI_REGISTRY_IMAGE`    |
| `cache_tag`         | `CACHE_TAG`         | Tag of the Docker image used to cache layers                        | `string` | `latest`                |
| `kaniko_tag`        |                     | Kaniko docker image tag. THe job needs debug variants of Kaniko.    | `string` | `v1.23.2-debug`         |

#### Examples

```yaml
stages:
  - build

include:
  - component: gitlab.sauerburger.com/sauerburger-it/devops/kaniko-build@x.x.x
```

### Docker build
The `docker-build` CI/CD component provides a template to build Docker images within a pipeline using the Docker engine. Make sure the Docker engine is available in the runner environment.
By default, it runs only for tagged commits.

#### Parameter

| Parameter           | Variable            | Description                                                         | Type     | Default                                        |
| ------------------- | ------------------- | ------------------------------------------------------------------- | -------- | ---------------------------------------------- |
| `stage`             |                     | Stage of the CI/CD job                                              | `string` | `build`                                        |
| `job_name`          |                     | Name of the CI/CD job                                               | `string` | `docker-build`                                 |
| `dockerfile`        | `DOCKERFILE`        | Path of the Dockerfile relative to the project directory.           | `string` | `Dockerfile`                                   |
| `image_repo`        | `IMAGE_REPO`        | Name of the Docker repository including the registry path           | `string` | `$CI_REGISTRY_IMAGE`                           |
| `image_tag`         | `IMAGE_TAG`         | Tag of the Docker image                                             | `string` | `$CI_COMMIT_TAG`                               |
| `project_dir`       | `PROJECT_DIR`       | Project directory and docker context.                               | `string` | `$CI_PROJECT_DIR`                              |
| `registry`          | `REGISTRY`          | Hostname (and port) of the Docker registry to which the job logs in | `string` | `$CI_REGISTRY`                                 |
| `registry_user`     | `REGISTRY_USER`     | Username to authenticate with the Docker registry                   | `string` | `$CI_REGISTRY_USER`                            |
| `registry_password` | `REGISTRY_PASSWORD` | Password to authenticate with the Docker registry                   | `string` | `$CI_REGISTRY_PASSWORD`                        |
| `cache_repo`        | `CACHE_REPO`        | Name of the Docker repository used to cache layers                  | `string` | `$CI_REGISTRY_IMAGE`                           |
| `cache_tag`         | `CACHE_TAG`         | Tag of the Docker image used to cache layers                        | `string` | `latest`                                       |
| `kaniko_image`      |                     | Kaniko Docker image. The job needs debug variant of Kaniko.         | `string` | `gcr.io/kaniko-project/executor:v1.23.2-debug` |

#### Examples

```yaml
stages:
  - build

include:
  - component: gitlab.sauerburger.com/sauerburger-it/devops/kaniko-build@x.x.x
```

### Docker image retag

The `buildx-retag` CI/CD component provides a template to push existing Docker image to the registry using a different tag. The
operation doesn't require the job to download the image artifacts.
By default, it runs only for tagged commits and if triggered manually.

#### Parameter

| Parameter           | Variables           | Description                                                         | Type     | Default                             |
| ------------------- | ------------------- | ------------------------------------------------------------------- | -------- | ----------------------------------- |
| `stage`             |                     | Stage of the CI/CD job                                              | `string` | `deploy`                            |
| `name`              |                     | Name of the CI/CD job                                               | `string` | `tag-latest`                        |
| `source`            | `SOURCE`            | Repository and tag of the existing source Docker image.             | `string` | `$CI_REGISTRY_IMAGE:$CI_COMMIT_TAG` |
| `target`            | `TARGET`            | Repository and tag of the Docker image to push.                     | `string` | `$CI_REGISTRY_IAMGE:latest`         |
| `registry`          | `REGISTRY`          | Hostname (and port) of the Docker registry to which the job logs in | `string` | `$CI_REGISTRY`                      |
| `registry_user`     | `REGISTRY_USER`     | Username to authenticate with the Docker registry                   | `string` | `$CI_REGISTRY_USER`                 |
| `registry_password` | `REGISTRY_PASSWORD` | Password to authenticate with the Docker registry                   | `string` | `$CI_REGISTRY_PASSWORD`             |
| `docker_tag`        |                     | "Docker" Docker image tag.                                          | `string` | `25.0.3-cli`                        |

#### Examples

```yaml
stages:
  - deploy

include:
  - component: gitlab.sauerburger.com/sauerburger-it/devops/buildx-retag@x.x.x
```

### Deploy static Kubernetes manifest
Deploy an application defined in a Kubernetes manifest using kubectl. The manifest
is passed through envsubst so that environment variables are replaced with their variables.
The job name starts with a dot to prevent it from being executed directly.

#### Parameter

| Parameter      | Variables    | Description                                               | Type     | Default             |
| -------------- | ------------ | --------------------------------------------------------- | -------- | ------------------- |
| `agent_name`   | `AGENT_NAME` | Name of the Kubernetes agent without the repository info. | `string` | *(mandatory)*       |
| `namespace`    | `NAMESPACE`  | Namespace used in `kubectl apply`                         | `string` | *(mandatory)*       |
| `stage`        |              | Stage of the CI/CD job.                                   | `string` | `deploy`            |
| `job_name`     |              | Name of the CI/CD job                                     | `string` | `.kubectl-deploy`   |
| `agent_repo`   | `AGENT_REPO` | Repository path and name of the Kubernetes agent          | `string` | `$CI_PROJECT_PATH`  |
| `manifest`     | `MANIFEST`   | Filename of the Kubernetes manifest to `apply`            | `string` | `kubernetes.yaml`   |
| `docker_image` |              | "kubectl" Docker image.                                   | `string` | `alpine/k8s:1.28.3` |

#### Examples

```yaml
stages:
  - deploy

include:
  - component: gitlab.sauerburger.com/sauerburger-it/devops/kubectl-deploy@x.x.x

deploy:staging:
  extends: .kubectl-deploy
  variables:
    AGENT_NAME: stratus-staging
    NAMESPACE: app-staging

deploy:production:
  extends: .kubectl-deploy
  when: manual
  variables:
    AGENT_NAME: stratus
    NAMESPACE: app
```

### Helm deployment

Deploy an application defined as Helm chart. The chart's values file
is passed through envsubst so that environment variables are replaced with their variables.
The job name starts with a dot to prevent it from being executed directly.

#### Parameter

| Input          | Variable       | Description                                                                           | Default             |
| -------------- | -------------- | ------------------------------------------------------------------------------------- | ------------------- |
| `agent_name`   | `AGENT_NAME`   | Name of the Kubernetes agent without the repository info.                             | *(mandatory)*       |
| `namespace`    | `NAMESPACE`    | Namespace used in `kubectl apply`                                                     | *(mandatory)*       |
| `release_name` | `RELEASE_NAME` | Name of the installed Helm chart instance                                             | *(mandatory)*       |
| `stage`        |                | Stage of the CI/CD job.                                                               | `deploy`            |
| `job_name`     |                | Name of the CI/CD job                                                                 | `.helm-deploy`      |
| `agent_repo`   | `AGENT_REPO`   | Repository info of the Kubernetes agent                                               | `$CI_PROJECT_PATH`  |
| `values`       | `VALUES`       | Filename of the Helm chart values                                                     | `values.yaml`       |
| `chart_path`   | `CHART_PATH`   | Path to the chart                                                                     | `chart/`            |
| `timeout`      | `TIMEOUT`      | Timeout for helm to wait until deployment is up, default 10 minutes. Requires a unit. | `10m`               |
| `aux_args`     | `AUX_ARGS`     | Additional arguments passed to `helm upgrade`                                         | `""`                |
| `docker_image` |                | Docker image with `kubectl`                                                           | `alpine/k8s:1.28.3` |

#### Example

```yaml
stages:
  - deploy

include:
  - component: gitlab.mdpi.com:8081/ai/libraries/ci-templates/helm-deploy@x.x.x

deploy:staging:
  extends: .kubectl-deploy
  variables:
    AGENT_NAME: stratus-staging
    NAMESPACE: app-staging
    RELEASE_NAME: app-staging

deploy:production:
  extends: .kubectl-deploy
  when: manual
  variables:
    AGENT_NAME: stratus
    NAMESPACE: app
    RELEASE_NAME: app
```